@@ -143,7 +143,7 @@ def _secret_redaction_processor(_, __, event_dict):
     Returns:
         structlog.typing.EventDict: The processed event dictionary.
     """
-    sensitive_keys = ["password", "api_key", "token", "SecretString"]
+    sensitive_keys = ["password", "api_key", "token", "SecretString", "key", "auth"]
 
     def redact_dict(data):
         """Recursively redact sensitive keys in nested dictionaries.
